==> nextcloud-30.0.10.tgz: nextcloud/apps/viewer/l10n/id.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Penampil",
    "Simple file viewer with slideshow for media" : "Penampil berkas sederhana dengan pertunjukan salindia bagi media",
    "Your browser does not support audio." : "Peramban Anda tidak mendukung suara.",
    "Error loading {name}" : "Kesalahan saat memuat {name}",
    "Image saved" : "Gambar disimpan",
    "Error saving image" : "Kesalahan saat menyimpan citra",
    "Unsaved changes" : "Perubahan belum disimpan",
    "Drop changes" : "Buang perubahan",
    "Your browser does not support videos." : "Peramban Anda tidak mendukung video.",
    "This file no longer exists" : "Berkas ini tidak ada lagi",
    "There is no plugin available to display this file type" : "Tidak tersedia plugin untuk menampilkan tipe berkas ini",
    "Edit" : "Sunting",
    "Exit full screen" : "Keluar layar penuh",
    "Full screen" : "Layar penuh",
    "Open sidebar" : "Buka jendela samping",
    "Download" : "Unduh",
    "Delete" : "Hapus",
    "View" : "Tampilan",
    "Name" : "Nama",
    "Save" : "Simpan",
    "Save as" : "Simpan sebagai",
    "Back" : "Kembali",
    "Loading …" : "Memuat …",
    "Reset" : "Setel ulang",
    "All changes will be lost." : "Semua perubahan akan hilang.",
    "Are you sure you want to continue?" : "Anda yakin ingin melanjutkan?",
    "Cancel" : "Membatalkan",
    "Apply" : "Terapkan",
    "Warning" : "Peringatan",
    "Confirm" : "Konfirmasi",
    "Discard changes" : "Buang perubahan",
    "Undo" : "Undo",
    "Redo" : "Ulang lagi",
    "Show original image" : "Tampilkan gambar asli",
    "Zoom in" : "Perbesar",
    "Zoom out" : "Perkecil",
    "Toggle zoom menu" : "Jungkitkan menu zum",
    "Adjust" : "Setel",
    "Filters" : "Penyaring",
    "Watermark" : "Tanda air",
    "Draw" : "Gambar",
    "Resize" : "Ubah ukuran",
    "Image name" : "Nama citra",
    "Invalid image." : "Citra tidak valid.",
    "Error while uploading the image." : "Terjadi kesalahan saat memuat citra.",
    "are not images" : "bukan citra",
    "is not an image" : "bukan citra",
    "to be uploaded" : "untuk diunggah",
    "Crop" : "Pangkas",
    "Original" : "Asli",
    "Custom" : "Ubahan",
    "Square" : "Bujur sangkar",
    "Landscape" : "Lansekap",
    "Portrait" : "Potret",
    "Ellipse" : "Elips",
    "Classic TV" : "TV klasik",
    "Arrow" : "Panah",
    "Blur" : "Kabur",
    "Brightness" : "Kecerahan",
    "Contrast" : "Kontras",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "Saturasi",
    "Value" : "Nilari",
    "Image" : "Gambar",
    "Importing …" : "Mengimpor …",
    "+ Add image" : "+ Tambah citra",
    "Upload image" : "Unggah citra",
    "From gallery" : "Dari galeri",
    "Line" : "Garis",
    "Pen" : "Pena",
    "Polygon" : "Poligon",
    "Text" : "Teks",
    "Size" : "Ukuran",
    "Menu" : "Menu"
},
"nplurals=1; plural=0;");

==> nextcloud-30.0.11.tgz: nextcloud/apps/viewer/l10n/id.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Penampil",
    "Simple file viewer with slideshow for media" : "Penampil berkas sederhana dengan pertunjukan salindia bagi media",
    "Your browser does not support audio." : "Peramban Anda tidak mendukung suara.",
    "Error loading {name}" : "Kesalahan saat memuat {name}",
    "Image saved" : "Gambar disimpan",
    "Error saving image" : "Kesalahan saat menyimpan citra",
    "Unsaved changes" : "Perubahan belum disimpan",
    "Drop changes" : "Buang perubahan",
    "Your browser does not support videos." : "Peramban Anda tidak mendukung video.",
    "This file no longer exists" : "Berkas ini tidak ada lagi",
    "There is no plugin available to display this file type" : "Tidak tersedia plugin untuk menampilkan tipe berkas ini",
    "Edit" : "Sunting",
    "Exit full screen" : "Keluar layar penuh",
    "Full screen" : "Layar penuh",
    "Open sidebar" : "Buka jendela samping",
    "Download" : "Unduh",
    "Delete" : "Hapus",
    "View" : "Tampilan",
    "Name" : "Nama",
    "Save" : "Simpan",
    "Save as" : "Simpan sebagai",
    "Back" : "Kembali",
    "Loading …" : "Memuat …",
    "Reset" : "Setel ulang",
    "All changes will be lost." : "Semua perubahan akan hilang.",
    "Are you sure you want to continue?" : "Anda yakin ingin melanjutkan?",
    "Cancel" : "Membatalkan",
    "Apply" : "Terapkan",
    "Warning" : "Peringatan",
    "Confirm" : "Konfirmasi",
    "Discard changes" : "Buang perubahan",
    "Undo" : "Undo",
    "Redo" : "Ulang lagi",
    "Show original image" : "Tampilkan gambar asli",
    "Zoom in" : "Perbesar",
    "Zoom out" : "Perkecil",
    "Toggle zoom menu" : "Jungkitkan menu zum",
    "Adjust" : "Setel",
    "Filters" : "Penyaring",
    "Watermark" : "Tanda air",
    "Draw" : "Gambar",
    "Resize" : "Ubah ukuran",
    "Image name" : "Nama citra",
    "Invalid image." : "Citra tidak valid.",
    "Error while uploading the image." : "Terjadi kesalahan saat memuat citra.",
    "are not images" : "bukan citra",
    "is not an image" : "bukan citra",
    "to be uploaded" : "untuk diunggah",
    "Crop" : "Pangkas",
    "Original" : "Asli",
    "Custom" : "Ubahan",
    "Square" : "Bujur sangkar",
    "Landscape" : "Lansekap",
    "Portrait" : "Potret",
    "Ellipse" : "Elips",
    "Classic TV" : "TV klasik",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Panah",
    "Blur" : "Kabur",
    "Brightness" : "Kecerahan",
    "Contrast" : "Kontras",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "Saturasi",
    "Value" : "Nilari",
    "Image" : "Gambar",
    "Importing …" : "Mengimpor …",
    "+ Add image" : "+ Tambah citra",
    "Upload image" : "Unggah citra",
    "From gallery" : "Dari galeri",
    "Line" : "Garis",
    "Pen" : "Pena",
    "Polygon" : "Poligon",
    "Rectangle" : "Persegi Panjang",
    "Corner Radius" : "Jari-jari Sudut",
    "Width in pixels" : "Lebar dalam piksel",
    "Height in pixels" : "Tinggi dalam piksel",
    "Reset to original image size" : "Setel ulang ke ukuran citra asli",
    "Rotate" : "Putar",
    "Text" : "Teks",
    "Text alignment" : "Perataan teks",
    "Font family" : "Keluarga fonta",
    "Size" : "Ukuran",
    "Line height" : "Tinggi baris",
    "+ Add watermark" : "+ Tambah tanda air",
    "+ Add text watermark" : "+ Tambah tanda air teks",
    "Choose watermark type" : "Pilih tipe tanda air",
    "Upload watermark" : "Unggah tanda air",
    "Add as text" : "Tambahkan sebagai teks",
    "Shadow" : "Bayangan",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertikal",
    "Opacity" : "Kelegapan",
    "Position" : "Posisi",
    "Save image as" : "Simpan citra sebagai",
    "Extension" : "Ekstensi",
    "Format" : "Format",
    "Name is required." : "Nama diperlukan.",
    "Quality" : "Kualitas",
    "Saved image size (width x height)" : "Ukuran citra tersimpan (lebar x tinggi)",
    "Actual size (100%)" : "Ukuran sebenarnya (100%)",
    "Fit size" : "Pas ukuran",
    "Select image to add …" : "Pilih citra yang akan ditambahkan ...",
    "Failed to load image." : "Gagal memuat citra.",
    "Menu" : "Menu",
    "Width" : "Lebar",
    "Height" : "Tinggi"
},
"nplurals=1; plural=0;");
